<%-- $Id: progress.jsp 4510 2008-09-11 20:03:48Z jari $
	------------------------------------------------------------------
	Copyright (C) 2005 Nicklas Nordborg
	Copyright (C) 2006 Jari Hakkinen, Nicklas Nordborg
	Copyright (C) 2007 Johan Enell

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
	------------------------------------------------------------------

	This page is used to display the progress of a file upload. The FileUploadProgress
	is put into the session setting by the upload.jsp page when the upload is started.
	If an exception is thrown during the upload we can get it by checking the
	FileUploadProgress.getException() method. 
	
	If we want to abort the upload we use the FileUpload.setAbort() method, which is
	detected by the upload process and causes an UploadAbortedException to be thrown.
	This exception is also detected by the FileUploadProgress.getException() method
	before we display the message about the aborted upload.

	@author Nicklas
	@version 2.0
--%>
<%@ page session="false"
	import="net.sf.basedb.core.SessionControl"
	import="net.sf.basedb.core.SimpleAbsoluteProgressReporter"
	import="net.sf.basedb.clients.web.Base"
	import="net.sf.basedb.util.Values"
	import="net.sf.basedb.clients.web.util.HTML"
	import="net.sf.basedb.clients.web.fileupload.FileUploadProgress"
	import="net.sf.basedb.clients.web.fileupload.UploadAbortedException"
%>
<%@ taglib prefix="base" uri="/WEB-INF/base.tld" %>
<%

final SessionControl sc = Base.getExistingSessionControl(pageContext, true);
final String ID = sc.getId();
final boolean abort = Values.getBoolean(request.getParameter("abort"));
final boolean ajax = Values.getBoolean(request.getParameter("ajax"));
final FileUploadProgress progress = (FileUploadProgress)sc.getSessionSetting("FileUploadProgress");
final SimpleAbsoluteProgressReporter unpackProgress = (SimpleAbsoluteProgressReporter)sc.getSessionSetting("UnpackProgress");

boolean transferIsComplete = false;
boolean failed = false;
long total = 0;
long transferred = 0;
long seconds = 0;
long remain = 0;
String currentFileName = "";
String unpackMessage = "";
if (progress != null)
{
	failed = progress.getException() != null;
	if (abort) progress.setAbort();
	currentFileName = progress.getCurrentFilename();
	total = progress.getTotalBytes();
	transferred = progress.getTransferredBytes();
	transferIsComplete = progress.transferIsComplete();
	seconds = progress.getMillisecondsSinceStart() / 1000;
	long transferRate = seconds != 0 ? transferred/seconds : 0;
	remain = transferRate != 0 ? (total-transferred)/transferRate : 0;
}
if (unpackProgress != null)
{
	unpackMessage = unpackProgress.getMessage();
}

String onload = "";
if (transferIsComplete)
{
	onload = "displayProgress(true)";
	sc.setSessionSetting("FileUploadProgress", null);
	sc.setSessionSetting("UnpackProgress", null);
}
else if (abort)
{
	onload = "uploadAborted()";
	sc.setSessionSetting("FileUploadProgress", null);
	sc.setSessionSetting("UnpackProgress", null);
}
else if (failed)
{
	onload = "displayException()";
}
else if (progress != null)
{
	onload = "displayProgress(false)";
}
else
{
	onload = "setTimeout('location.reload()', 1500)";
}
if (ajax)
{
	%><%=currentFileName%>:<%=transferred%>:<%=total%>:<%=seconds%>:<%=remain%>:<%=unpackMessage == null ? "" : unpackMessage%><%
}
else
{
	%>
	<html>
	<head>
	</head>
	<body onload="<%=onload%>">
		<script language="javascript">
		function displayProgress(isComplete)
		{
			var fileName = '<%=HTML.javaScriptEncode(currentFileName)%>';
			var transferredBytes = <%=transferred%>;
			var totalBytes = <%=total%>;
			var transferTime = <%=seconds%>;
			var remainTime = <%=remain%>;
			var unpackMessage = '<%=HTML.javaScriptEncode(unpackMessage)%>';
			window.top.frames['select'].displayProgress(fileName, transferredBytes, totalBytes, transferTime, remainTime, unpackMessage);
			if (!isComplete) 
			{
				setTimeout('location.reload()', 1500);
			}
		}
		function displayException()
		{
			window.top.frames['select'].location = 'show_exception.jsp?ID=<%=ID%>';
		}
		function uploadAborted()
		{
			window.top.location = '../../common/close_popup.jsp?refresh_opener=1&message=<%=HTML.urlEncode("The upload was aborted before it was completed.")%>';
		}
		</script>
	</body>
	</html>
	<%
}
%>
